==> ejc-middlemeasurement-impl-3.0.0-20220412.090131-33-sources.jar: com/ejianc/business/middlemeasurement/bean/CapitalinflowsEntity.java <==
package com.ejianc.business.middlemeasurement.bean;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.middlemeasurement.bean.CapitalinflowsdetailEntity;
/**
 * 资金流入
 * 
 * @author generator
 * 
 */
 @TableName("ejc_middlemeasurement_capitalinflows")
public class CapitalinflowsEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编号
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目id
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="org_id")
    private java.lang.Long orgId; // 所属组织id
    @TableField(value="org_name")
    private java.lang.String orgName; // 所属组织名称
    @TableField(value="project_department_id")
    private java.lang.Long projectDepartmentId; // 项目部id
    @TableField(value="deadline")
    private java.util.Date deadline; // 截至时间 
    @TableField(value="operational_total")
    private java.math.BigDecimal operationalTotal; // 经营性流入合计
    @TableField(value="received_payment")
    private java.math.BigDecimal receivedPayment; // 已收工程款
    @TableField(value="financing")
    private java.math.BigDecimal financing; // 筹资及其它流入合计
    @TableField(value="total")
    private java.math.BigDecimal total; // 合计
    @TableField(value="other_income")
    private java.math.BigDecimal otherIncome;//其他 --经营性
    @TableField(value="company_invested")
    private java.math.BigDecimal companyInvested;//公司投入（元）
    @TableField(value="other")
    private java.math.BigDecimal other;//其它（元）

    public BigDecimal getOtherIncome() {
        return otherIncome;
    }

    public void setOtherIncome(BigDecimal otherIncome) {
        this.otherIncome = otherIncome;
    }

    public BigDecimal getCompanyInvested() {
        return companyInvested;
    }

    public void setCompanyInvested(BigDecimal companyInvested) {
        this.companyInvested = companyInvested;
    }

    public BigDecimal getOther() {
        return other;
    }

    public void setOther(BigDecimal other) {
        this.other = other;
    }

//    @TableField(exist=false)
//    @SubEntity(serviceName="capitalinflowsdetailService",pidName = "mid")
//    private List<CapitalinflowsdetailEntity> capitalinflowsdetailEntities = new ArrayList<>(); // 资金流入子表


    

    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 项目id
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 截至时间 
     */
    public java.util.Date getDeadline() {
        return deadline;
    }

    /**
     * 截至时间 
     */
    public void setDeadline(java.util.Date deadline) {
        this.deadline = deadline;
    }
    /**
     * 经营性流入合计
     */
    public java.math.BigDecimal getOperationalTotal() {
        return operationalTotal;
    }

    /**
     * 经营性流入合计
     */
    public void setOperationalTotal(java.math.BigDecimal operationalTotal) {
        this.operationalTotal = operationalTotal;
    }
    /**
     * 已收工程款
     */
    public java.math.BigDecimal getReceivedPayment() {
        return receivedPayment;
    }

    /**
     * 已收工程款
     */
    public void setReceivedPayment(java.math.BigDecimal receivedPayment) {
        this.receivedPayment = receivedPayment;
    }
    /**
     * 筹资及其它流入合计
     */
    public java.math.BigDecimal getFinancing() {
        return financing;
    }

    /**
     * 筹资及其它流入合计
     */
    public void setFinancing(java.math.BigDecimal financing) {
        this.financing = financing;
    }
    /**
     * 合计
     */
    public java.math.BigDecimal getTotal() {
        return total;
    }

    /**
     * 合计
     */
    public void setTotal(java.math.BigDecimal total) {
        this.total = total;
    }
    
//    /**
//     * 资金流入子表
//     */
//    public List<CapitalinflowsdetailEntity> getCapitalinflowsdetailEntities() {
//        return capitalinflowsdetailEntities;
//    }
//
//    /**
//     * 资金流入子表
//     */
//    public void setCapitalinflowsdetailEntities(List<CapitalinflowsdetailEntity> capitalinflowsdetailEntities) {
//        this.capitalinflowsdetailEntities = capitalinflowsdetailEntities;
//    }
}

==> ejc-middlemeasurement-impl-3.0.0-20221219.062630-293-sources.jar: com/ejianc/business/middlemeasurement/bean/CapitalinflowsEntity.java <==
package com.ejianc.business.middlemeasurement.bean;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.middlemeasurement.bean.CapitalinflowsdetailEntity;
/**
 * 资金流入
 * 
 * @author generator
 * 
 */
 @TableName("ejc_middlemeasurement_capitalinflows")
public class CapitalinflowsEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编号
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目id
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="org_id")
    private java.lang.Long orgId; // 所属组织id
    @TableField(value="org_name")
    private java.lang.String orgName; // 所属组织名称
    @TableField(value="project_department_id")
    private java.lang.Long projectDepartmentId; // 项目部id
    @TableField(value="deadline")
    private java.util.Date deadline; // 截至时间 
    @TableField(value="operational_total")
    private java.math.BigDecimal operationalTotal; // 经营性流入合计
    @TableField(value="received_payment")
    private java.math.BigDecimal receivedPayment; // 已收工程款
    @TableField(value="financing")
    private java.math.BigDecimal financing; // 筹资及其它流入合计
    @TableField(value="total")
    private java.math.BigDecimal total; // 合计
    @TableField(value="other_income")
    private java.math.BigDecimal otherIncome;//其他 --经营性
    @TableField(value="company_invested")
    private java.math.BigDecimal companyInvested;//公司投入（元）
    @TableField(value="other")
    private java.math.BigDecimal other;//其它（元）
    @TableField(value = "save_time")
    private java.util.Date saveTime;

    public Date getSaveTime() {
        return saveTime;
    }

    public void setSaveTime(Date saveTime) {
        this.saveTime = saveTime;
    }

    public BigDecimal getOtherIncome() {
        return otherIncome;
    }

    public void setOtherIncome(BigDecimal otherIncome) {
        this.otherIncome = otherIncome;
    }

    public BigDecimal getCompanyInvested() {
        return companyInvested;
    }

    public void setCompanyInvested(BigDecimal companyInvested) {
        this.companyInvested = companyInvested;
    }

    public BigDecimal getOther() {
        return other;
    }

    public void setOther(BigDecimal other) {
        this.other = other;
    }

//    @TableField(exist=false)
//    @SubEntity(serviceName="capitalinflowsdetailService",pidName = "mid")
//    private List<CapitalinflowsdetailEntity> capitalinflowsdetailEntities = new ArrayList<>(); // 资金流入子表


    

    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 项目id
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 截至时间 
     */
    public java.util.Date getDeadline() {
        return deadline;
    }

    /**
     * 截至时间 
     */
    public void setDeadline(java.util.Date deadline) {
        this.deadline = deadline;
    }
    /**
     * 经营性流入合计
     */
    public java.math.BigDecimal getOperationalTotal() {
        return operationalTotal;
    }

    /**
     * 经营性流入合计
     */
    public void setOperationalTotal(java.math.BigDecimal operationalTotal) {
        this.operationalTotal = operationalTotal;
    }
    /**
     * 已收工程款
     */
    public java.math.BigDecimal getReceivedPayment() {
        return receivedPayment;
    }

    /**
     * 已收工程款
     */
    public void setReceivedPayment(java.math.BigDecimal receivedPayment) {
        this.receivedPayment = receivedPayment;
    }
    /**
     * 筹资及其它流入合计
     */
    public java.math.BigDecimal getFinancing() {
        return financing;
    }

    /**
     * 筹资及其它流入合计
     */
    public void setFinancing(java.math.BigDecimal financing) {
        this.financing = financing;
    }
    /**
     * 合计
     */
    public java.math.BigDecimal getTotal() {
        return total;
    }

    /**
     * 合计
     */
    public void setTotal(java.math.BigDecimal total) {
        this.total = total;
    }
    
//    /**
//     * 资金流入子表
//     */
//    public List<CapitalinflowsdetailEntity> getCapitalinflowsdetailEntities() {
//        return capitalinflowsdetailEntities;
//    }
//
//    /**
//     * 资金流入子表
//     */
//    public void setCapitalinflowsdetailEntities(List<CapitalinflowsdetailEntity> capitalinflowsdetailEntities) {
//        this.capitalinflowsdetailEntities = capitalinflowsdetailEntities;
//    }
}
